
Welcome to the Sudio 🎵
=======================


used to manipulate, edit, and analyze digital audio with ease. 
It offers a range of tools for working with sound files, 
including slicing, filtering, mixing, and applying effects across different audio formats.

.. raw:: html
   
   <br>


.. image:: https://raw.githubusercontent.com/mrzahaki/sudio/Master/docs/_static/sudio.png
   :alt: sudio
   :width: 60%
   :align: center
   :class: no-click

.. raw:: html
   
   <br>

.. image:: https://badge.fury.io/py/sudio.svg
   :target: https://badge.fury.io/py/sudio

.. image:: https://static.pepy.tech/badge/sudio
   :target: https://www.pepy.tech/projects/sudio

.. image:: https://img.shields.io/badge/docs-github%20pages-blue
   :target: https://mrzahaki.github.io/sudio/

.. image:: https://github.com/mrzahaki/sudio/actions/workflows/python-package.yml/badge.svg
   :target: https://github.com/mrzahaki/sudio/actions/workflows/python-package.yml

.. image:: https://img.shields.io/pypi/pyversions/sudio.svg
   :target: https://pypi.org/project/sudio/

.. image:: https://img.shields.io/badge/OS-Linux%20%7C%20macOS%20%7C%20Windows-blue
   :target: https://shields.io/

.. image:: https://img.shields.io/badge/License-Apache%202.0-blue.svg
   :target: https://opensource.org/licenses/Apache-2.0

.. image:: https://colab.research.google.com/assets/colab-badge.svg
   :target: https://colab.research.google.com/github/mrzahaki/sudio/blob/Master/docs/_static/sudio.ipynb

.. raw:: html
   
   <br>

.. raw:: html

   <br>
   <div align="center">
   I always finish my projec
   </div>
   <div align="center"> If 🎵 <b>Sudio</b> 🎶 has been helpful to you, consider supporting its development.</div>
   <br>



.. raw:: html

   <div style="text-align: center;">
       <a href="https://ko-fi.com/T6T5JXCVA">
           <img src="https://ko-fi.com/img/githubbutton_sm.svg" alt="ko-fi">
       </a>
   </div>


.. raw:: html

   <script src='https://storage.ko-fi.com/cdn/scripts/overlay-widget.js'></script>
   <script>
     kofiWidgetOverlay.draw('mrzahaki', {
       'type': 'floating-chat',
       'floating-chat.donateButton.text': 'Support me',
       'floating-chat.donateButton.background-color': '#2980b9',
       'floating-chat.donateButton.text-color': '#fff'
     });
   </script>
   <br><br><br><br>


.. include:: installation.rst
.. include:: start.rst


LICENCE
-------

Sudio is released under the GNU AFFERO GENERAL PUBLIC LICENSE Version 3. See the `LICENSE <https://github.com/mrzahaki/sudio/blob/Master/LICENSE>`_ file for details.





.. toctree::
   :maxdepth: 10
   :caption: Contents

   installation
   start 
   core
   pipeline
   audiosys
   api/io_root
   io
   metadata
   stream
   types
   utils
   rateshift
   process
   Source code <https://github.com/mrzahaki/sudio>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
